# Copyright 2024- Le Filament (https://le-filament.com)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html)

from odoo import api, fields, models


class Lead(models.Model):
    _inherit = "crm.lead"
    DEFAULT_EXPECTED_REVENUE_VAT = 0.2

    # ------------------------------------------------------
    # Fields declaration
    # ------------------------------------------------------
    expected_revenue = fields.Monetary("Revenu espéré HT")
    expected_revenue_incl_tax = fields.Monetary(
        "Revenu espéré TTC",
        currency_field="company_currency",
        compute="_compute_expected_revenue_incl_tax",
        inverse="_inverse_expected_revenue",
        store=True,
    )

    # ------------------------------------------------------
    # SQL Constraints
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Default methods
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Computed fields / Search Fields
    # ------------------------------------------------------
    @api.depends("expected_revenue")
    def _compute_expected_revenue_incl_tax(self):
        for lead in self:
            lead.expected_revenue_incl_tax = (
                (lead.expected_revenue * (1 + Lead.DEFAULT_EXPECTED_REVENUE_VAT))
                if lead.expected_revenue
                else 0
            )

    def _inverse_expected_revenue(self):
        for lead in self:
            lead.expected_revenue = (
                (
                    lead.expected_revenue_incl_tax
                    / (1 + Lead.DEFAULT_EXPECTED_REVENUE_VAT)
                )
                if lead.expected_revenue_incl_tax
                else 0
            )

    # ------------------------------------------------------
    # Onchange / Constraints
    # ------------------------------------------------------
    @api.onchange("expected_revenue_incl_tax")
    def _onchange_expected_revenue_incl_tax(self):
        self._inverse_expected_revenue()

    # ------------------------------------------------------
    # CRUD methods (ORM overrides)
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Actions
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Business methods
    # ------------------------------------------------------
